@@ -32,6 +32,12 @@
 #' imported.
 #' @param font_size A numeric input for table font size
 #'
+#' @examples x_html <- knitr::kable(head(mtcars), "html")
+#' kable_styling(x_html, "striped", position = "left", font_size = 7)
+#'
+#' x_latex <- knitr::kable(head(mtcars), "latex")
+#' kable_styling(x_latex, latex_options = "striped", position = "float_left")
+#'
 #' @export
 kable_styling <- function(kable_input,
                           bootstrap_options = "basic",
@@ -169,14 +175,6 @@ pdfTable_styling <- function(kable_input,
   out <- NULL
   out <- as.character(kable_input)
   table_info <- magic_mirror(kable_input)
-  table_info$valign2 <- sub("\\[", "\\\\[", table_info$valign)
-  table_info$valign2 <- sub("\\]", "\\\\]", table_info$valign2)
-  table_info$valign3 <- sub("\\[", "", table_info$valign)
-  table_info$valign3 <- sub("\\]", "", table_info$valign3)
-  table_info$begin_tabular <- paste0("\\\\begin\\{", table_info$tabular, "\\}",
-                                     table_info$valign2)
-  table_info$end_tabular <- paste0("\\\\end\\{", table_info$tabular, "\\}")
-
 
   if ("striped" %in% latex_options) {
     out <- styling_latex_striped(out)
